@@ -1,7 +1,7 @@
 import os
 
-# from django.conf import settings
-from django_sourcerer import settings
+from django.conf import settings
+
 from django_sourcerer.import_datas import parsing_config_file
 from django_sourcerer.import_datas.import_csv_data import HandleCsvData
 
@@ -36,5 +36,5 @@ class Adapter(object):
         dict_of_columns_fields = dict(zip(self.columns, self.fields))
         return dict_of_columns_fields
 
-    def parse_models_name(self):
+    def model_name(self):
         return self.name
