@@ -4,24 +4,26 @@ from django_sourcerer.import_datas.intermediate_layer import Adapter
 
 
 class AutoModels:
-    ModelsFromConfFile = type(Adapter().parse_models_name(), (models.Model,), {
+    ModelsFromConfFile = type(Adapter().model_name(), (models.Model,), {
         '__module__': __name__,
     })
 
+    def use_model(self):
+        return self.ModelsFromConfFile
+
 
 class HandleModel:
 
     def parse_models(self):
         dic = Adapter().parse_models_values()
-
+        model = AutoModels().use_model()
         for k, v in dic.items():
-
             if v == 'str':
-                AutoModels.ModelsFromConfFile.add_to_class(k, models.CharField(max_length=255, null=True))
+                model.add_to_class(k, models.CharField(max_length=255, null=True))
             elif v == 'int':
-                AutoModels.ModelsFromConfFile.add_to_class(k, models.IntegerField(null=True))
+                model.add_to_class(k, models.IntegerField(null=True))
             elif v == 'text':
-                AutoModels.ModelsFromConfFile.add_to_class(k, models.TextField(max_length=255, null=True))
+                model.add_to_class(k, models.TextField(max_length=255, null=True))
 
 
 HandleModel().parse_models()
